package com.glxp.mipsdl.admin.client.file;

import com.glxp.mipsdl.admin.client.BaseFileClient;
import com.glxp.mipsdl.admin.req.system.*;
import com.glxp.mipsdl.admin.res.system.UdiwmsInvProductResponse;
import com.glxp.mipsdl.admin.res.system.UdiwmsProductInfoResponse;
import com.glxp.mipsdl.admin.res.system.UdiwmsUnitResponse;
import com.glxp.mipsdl.admin.thread.system.UdiInfoUploadService;
import com.glxp.mipsdl.common.res.BaseResponse;
import com.glxp.mipsdl.common.util.ResultVOUtils;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 高立新鹏自定义标准规范
 */
@Service
public class GlxpFileClient implements BaseFileClient {

    @Resource
    UdiInfoUploadService udiInfoUploadService;

    Logger logger = LoggerFactory.getLogger(GlxpFileClient.class);

    @Override
    public BaseResponse uploadPi(List<MultipartFile> files, String thirdSys) {
        for (int i = 0; i < files.size(); i++) {
            MultipartFile file = files.get(i);
            if (file.isEmpty()) {
                return ResultVOUtils.error(500, "上传第" + (i++) + "个文件失败");
            }
            String fileName = file.getOriginalFilename();
            try {
                InputStream inputStream = file.getInputStream();
                Workbook workbook = null;
                String filetype = fileName.substring(fileName.lastIndexOf("."));

                if (".xls".equals(filetype)) {
                    workbook = new HSSFWorkbook(inputStream);
                } else if (".xlsx".equals(filetype)) {
                    workbook = new XSSFWorkbook(inputStream);
                } else {
                    return ResultVOUtils.error(500, "请上传excel文件");
                }
                Sheet sheet = null;
                Row row = null;
                List<UdiwmsProductInfoResponse> udiwmsProductInfoResponses = new ArrayList<>();
                for (int j = 0; j < workbook.getNumberOfSheets(); j++) {
                    sheet = workbook.getSheetAt(j);
                    if (sheet == null) {
                        continue;
                    }
                    // 滤过第一行标题
                    row = sheet.getRow(0);
                    if ((row.getCell(0) == null || row.getCell(1) == null || row.getCell(2) == null
                            || row.getCell(3) == null || row.getCell(4) == null || row.getCell(5) == null) ||
                            (!"产品ID".equals(row.getCell(0).getStringCellValue())
                                    || !"产品名称".equals(row.getCell(1).getStringCellValue())
                                    || !"计量单位".equals(row.getCell(2).getStringCellValue())
                                    || !"规格型号".equals(row.getCell(3).getStringCellValue())
                                    || !"注册证号".equals(row.getCell(4).getStringCellValue())
                                    || !"生产厂家".equals(row.getCell(5).getStringCellValue()))) {
                        return ResultVOUtils.error(500, "文件格式错误！");
                    }
                    for (int k = sheet.getFirstRowNum(); k <= sheet.getLastRowNum(); k++) {
                        row = sheet.getRow(k);
                        if (row == null || row.getRowNum() <= 0) {
                            continue;
                        }
                        if (filterEmpty(row)) {
                            continue;
                        }
                        UdiwmsProductInfoResponse udiwmsProductInfoResponse = new UdiwmsProductInfoResponse();
                        Cell cell = row.getCell(0);
                        if (cell != null) {
                            cell.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setCode(cell.getStringCellValue());
                        }

                        Cell cell1 = row.getCell(1);
                        if (cell1 != null) {
                            cell1.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setName(cell1.getStringCellValue());
                        }
                        Cell cell2 = row.getCell(2);
                        if (cell2 != null) {
                            cell2.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setMeasname(cell2.getStringCellValue());
                        }
                        Cell cell3 = row.getCell(3);
                        if (cell3 != null) {
                            cell3.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setSpec(cell3.getStringCellValue());
                        }
                        Cell cell4 = row.getCell(4);
                        if (cell4 != null) {
                            cell4.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setRegisterNo(cell4.getStringCellValue());
                        }
                        Cell cell5 = row.getCell(5);
                        if (cell5 != null) {
                            cell5.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setManufactory(cell5.getStringCellValue());
                        }
                        Cell cell6 = row.getCell(6);
                        if (cell6 != null) {
                            cell6.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setSupName(cell6.getStringCellValue());
                        }
                        udiwmsProductInfoResponses.add(udiwmsProductInfoResponse);
                    }
                }

                logger.error("解析完" + System.currentTimeMillis());
                PostThrProductsRequest postThrProductsRequest = new PostThrProductsRequest();
                postThrProductsRequest.setDatas(udiwmsProductInfoResponses);
                postThrProductsRequest.setUploadType("文件导入");
                postThrProductsRequest.setThirdSys(thirdSys);
                udiInfoUploadService.postProducts(postThrProductsRequest);
                logger.error("上传完" + System.currentTimeMillis());
                workbook.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return ResultVOUtils.success("文件解析成功，正在上传，请稍后刷新查看");
    }

    @Override
    public BaseResponse uploadCorps(List<MultipartFile> files, String thirdSys) {
        String filePath = "D:\\udiwms\\filePath\\";
        File createFile = new File(filePath);
        if (!createFile.exists()) {
            createFile.mkdirs();
        }
        for (int i = 0; i < files.size(); i++) {
            MultipartFile file = files.get(i);
            if (file.isEmpty()) {
                return ResultVOUtils.error(500, "上传第" + (i++) + "个文件失败");
            }
            String fileName = file.getOriginalFilename();
            try {
                InputStream inputStream = file.getInputStream();
                Workbook workbook = null;
                String filetype = fileName.substring(fileName.lastIndexOf("."));

                if (".xls".equals(filetype)) {
                    workbook = new HSSFWorkbook(inputStream);
                } else if (".xlsx".equals(filetype)) {
                    workbook = new XSSFWorkbook(inputStream);
                } else {
                    return ResultVOUtils.error(500, "请上传excel文件");
                }
                Sheet sheet = null;
                Row row = null;
                List<UdiwmsUnitResponse> udiwmsProductInfoResponses = new ArrayList<>();
                for (int j = 0; j < workbook.getNumberOfSheets(); j++) {
                    sheet = workbook.getSheetAt(j);
                    if (sheet == null) {
                        continue;
                    }
                    // 滤过第一行标题
                    row = sheet.getRow(0);
                    if ((row.getCell(0) == null || row.getCell(1) == null || row.getCell(2) == null
                            || row.getCell(3) == null || row.getCell(4) == null || row.getCell(5) == null || row.getCell(6) == null) ||
                            (!"往来单位ID".equals(row.getCell(0).getStringCellValue())
                                    || !"往来单位名称".equals(row.getCell(1).getStringCellValue())
                                    || !"拼音简写".equals(row.getCell(2).getStringCellValue())
                                    || !"地址".equals(row.getCell(3).getStringCellValue())
                                    || !"社会信用号".equals(row.getCell(4).getStringCellValue())
                                    || !"联系人".equals(row.getCell(5).getStringCellValue())
                                    || !"联系电话".equals(row.getCell(6).getStringCellValue())
                            )) {
                        return ResultVOUtils.error(500, "文件格式错误！");
                    }
                    for (int k = sheet.getFirstRowNum(); k <= sheet.getLastRowNum(); k++) {
                        row = sheet.getRow(k);
                        if (row == null || row.getRowNum() <= 0) {
                            continue;
                        }
                        if (filterEmpty(row)) {
                            continue;
                        }
                        UdiwmsUnitResponse udiwmsProductInfoResponse = new UdiwmsUnitResponse();
                        Cell cell1 = row.getCell(0);
                        if (cell1 != null) {
                            cell1.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setUnitId(cell1.getStringCellValue());
                        }
                        Cell cell2 = row.getCell(1);
                        if (cell2 != null) {
                            cell2.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setName(cell2.getStringCellValue());
                        }

                        Cell cell3 = row.getCell(2);
                        if (cell3 != null) {
                            cell3.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setSpell(cell3.getStringCellValue());
                        }
                        Cell cell4 = row.getCell(3);
                        if (cell4 != null) {
                            cell4.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setAddr(cell4.getStringCellValue());
                        }
                        Cell cell5 = row.getCell(4);
                        if (cell5 != null) {
                            cell5.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setCreditNo(cell5.getStringCellValue());
                        }
                        Cell cell6 = row.getCell(5);
                        if (cell6 != null) {
                            cell6.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setContact(cell6.getStringCellValue());
                        }
                        Cell cell7 = row.getCell(6);
                        if (cell7 != null) {
                            cell7.setCellType(CellType.STRING);
                            udiwmsProductInfoResponse.setMobile(cell7.getStringCellValue());
                        }
                        udiwmsProductInfoResponses.add(udiwmsProductInfoResponse);
                    }
                }
                PostThrCorpRequest postThrProductsRequest = new PostThrCorpRequest();
                postThrProductsRequest.setCorps(udiwmsProductInfoResponses);
                postThrProductsRequest.setThirdSys(thirdSys);
                udiInfoUploadService.postCorps(postThrProductsRequest);
                workbook.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return ResultVOUtils.success("文件解析成功，正在上传，请稍后刷新查看");
    }

    @Override
    public BaseResponse uploadInvPi(List<MultipartFile> files, String thirdSys) {
        String filePath = "D:\\udiwms\\filePath\\";
        File createFile = new File(filePath);
        if (!createFile.exists()) {
            createFile.mkdirs();
        }
        for (int i = 0; i < files.size(); i++) {
            MultipartFile file = files.get(i);
            if (file.isEmpty()) {
                return ResultVOUtils.error(500, "上传第" + (i++) + "个文件失败");
            }
            String fileName = file.getOriginalFilename();
            try {
                InputStream inputStream = file.getInputStream();
                Workbook workbook = null;
                String filetype = fileName.substring(fileName.lastIndexOf("."));

                if (".xls".equals(filetype)) {
                    workbook = new HSSFWorkbook(inputStream);
                } else if (".xlsx".equals(filetype)) {
                    workbook = new XSSFWorkbook(inputStream);
                } else {
                    return ResultVOUtils.error(500, "请上传excel文件");
                }
                Sheet sheet = null;
                Row row = null;
                List<UdiwmsInvProductResponse> udiwmsProductInfoResponses = new ArrayList<>();
                for (int j = 0; j < workbook.getNumberOfSheets(); j++) {
                    sheet = workbook.getSheetAt(j);
                    if (sheet == null) {
                        continue;
                    }
                    // 滤过第一行标题
                    for (int k = sheet.getFirstRowNum(); k <= sheet.getLastRowNum(); k++) {
                        row = sheet.getRow(k);
                        if (row == null || row.getRowNum() <= 0) {
                            continue;
                        }
                        if (filterEmpty(row)) {
                            continue;
                        }
                        UdiwmsInvProductResponse udiwmsProductInfoResponse = new UdiwmsInvProductResponse();
                        Cell cell1 = row.getCell(0);
                        if (cell1 == null)
                            break;
                        cell1.setCellType(CellType.STRING);

                        udiwmsProductInfoResponse.setCode(cell1.getStringCellValue());
                        udiwmsProductInfoResponse.setName(row.getCell(1).getStringCellValue());
                        udiwmsProductInfoResponse.setSpec(row.getCell(2).getStringCellValue());
                        udiwmsProductInfoResponse.setCount((int) row.getCell(3).getNumericCellValue());
                        Cell cell5 = row.getCell(4);
                        cell5.setCellType(CellType.STRING);
                        udiwmsProductInfoResponse.setBatchNo(cell5.getStringCellValue());
                        Cell cell6 = row.getCell(5);
                        cell6.setCellType(CellType.STRING);
                        udiwmsProductInfoResponse.setWarehouseCode(cell6.getStringCellValue());
                        udiwmsProductInfoResponse.setWarehouseName(row.getCell(6).getStringCellValue());
                        Cell cell8 = row.getCell(7);
                        cell8.setCellType(CellType.STRING);
                        udiwmsProductInfoResponse.setRegisterCertNo(cell8.getStringCellValue());
                        Cell cell9 = row.getCell(8);
                        cell9.setCellType(CellType.STRING);
                        udiwmsProductInfoResponse.setManufacturingDate(cell9.getStringCellValue());
                        Cell cell10 = row.getCell(9);
                        cell10.setCellType(CellType.STRING);
                        udiwmsProductInfoResponse.setExpirationDate(cell10.getStringCellValue());
                        udiwmsProductInfoResponses.add(udiwmsProductInfoResponse);
                    }
                }
                PostThrInvProductsRequest postThrProductsRequest = new PostThrInvProductsRequest();
                postThrProductsRequest.setDatas(udiwmsProductInfoResponses);
                postThrProductsRequest.setThirdSys(thirdSys);
                udiInfoUploadService.postInvPi(postThrProductsRequest);
                workbook.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return ResultVOUtils.success("文件解析成功，正在上传，请稍后刷新查看");
    }

    @Override
    public BaseResponse uploadOrders(List<MultipartFile> files, String thirdSys) {
        String filePath = "D:\\udiwms\\filePath\\";
        File createFile = new File(filePath);
        if (!createFile.exists()) {
            createFile.mkdirs();
        }
        for (int i = 0; i < files.size(); i++) {
            MultipartFile file = files.get(i);
            if (file.isEmpty()) {
                return ResultVOUtils.error(500, "上传第" + (i++) + "个文件失败");
            }
            String fileName = file.getOriginalFilename();
            try {
                InputStream inputStream = file.getInputStream();
                Workbook workbook = null;
                String filetype = fileName.substring(fileName.lastIndexOf("."));

                if (".xls".equals(filetype)) {
                    workbook = new HSSFWorkbook(inputStream);
                } else if (".xlsx".equals(filetype)) {
                    workbook = new XSSFWorkbook(inputStream);
                } else {
                    return ResultVOUtils.error(500, "请上传excel文件");
                }
                Sheet sheet = null;
                Row row = null;
                PostFileThrOrderRequest thrOrderImportLogEntity = new PostFileThrOrderRequest();
                thrOrderImportLogEntity.setUploadType("文件导入");
                thrOrderImportLogEntity.setThirdSys(thirdSys);
                List<ThrOrderImportDetailEntity> corpImportDetailEntities = new ArrayList<>();
                for (int j = 0; j < 1; j++) {//workbook.getNumberOfSheets()
                    sheet = workbook.getSheetAt(j);
                    if (sheet == null) {
                        continue;
                    }
                    // 滤过第一行标题
                    row = sheet.getRow(0);
                    if ((row.getCell(0) == null || row.getCell(1) == null || row.getCell(2) == null
                            || row.getCell(3) == null || row.getCell(4) == null || row.getCell(5) == null || row.getCell(6) == null) ||
                            (!"单据号".equals(row.getCell(0).getStringCellValue())
                                    || !"单据日期".equals(row.getCell(1).getStringCellValue())
                                    || !"往来单位ID".equals(row.getCell(2).getStringCellValue())
                                    || !"往来单位名称".equals(row.getCell(3).getStringCellValue())
                                    || !"单据类型".equals(row.getCell(4).getStringCellValue())
                                    || !"单据状态".equals(row.getCell(5).getStringCellValue())
                                    || !"产品ID".equals(row.getCell(6).getStringCellValue()))) {
                        return ResultVOUtils.error(500, "文件格式错误！");
                    }
                    for (int k = sheet.getFirstRowNum() + 1; k <= sheet.getLastRowNum(); k++) {
                        row = sheet.getRow(k);
                        if (row == null || row.getRowNum() <= 0) {
                            continue;
                        }
                        if (filterEmpty(row)) {
                            continue;
                        }
                        ThrOrderImportDetailEntity corpImportDetailEntity = new ThrOrderImportDetailEntity();
                        Cell cell1 = row.getCell(0);
                        if (cell1 != null) {
                            cell1.setCellType(CellType.STRING);
                            corpImportDetailEntity.setBillNo(cell1.getStringCellValue());
                        }


                        Cell cell2 = row.getCell(1);
                        if (cell2 != null) {
                            cell2.setCellType(CellType.STRING);
                            corpImportDetailEntity.setBilldate(cell2.getStringCellValue());
                        }
                        Cell cell3 = row.getCell(2);
                        if (cell3 != null) {
                            cell3.setCellType(CellType.STRING);
                            corpImportDetailEntity.setCorpId(cell3.getStringCellValue());

                        }
                        Cell cell4 = row.getCell(3);
                        if (cell4 != null) {
                            cell4.setCellType(CellType.STRING);
                            corpImportDetailEntity.setCorpName(cell4.getStringCellValue());

                        }
                        Cell cell5 = row.getCell(4);
                        if (cell5 != null) {
                            cell5.setCellType(CellType.STRING);
                            String billType = cell5.getStringCellValue();
                            corpImportDetailEntity.setBillType(billType);


                        }
                        Cell cell6 = row.getCell(5);
                        if (cell6 != null) {
                            cell6.setCellType(CellType.STRING);
                            corpImportDetailEntity.setBillFlag(cell6.getStringCellValue());
                        }

                        Cell cell7 = row.getCell(6);
                        if (cell7 != null) {
                            cell7.setCellType(CellType.STRING);
                            corpImportDetailEntity.setProductId(cell7.getStringCellValue());
                        }

                        Cell cell8 = row.getCell(7);
                        if (cell8 != null) {
                            cell8.setCellType(CellType.STRING);
                            corpImportDetailEntity.setProductName(cell8.getStringCellValue());
                        }

                        Cell cell9 = row.getCell(8);
                        if (cell9 != null) {
                            cell9.setCellType(CellType.STRING);
                            corpImportDetailEntity.setSpec(cell9.getStringCellValue());
                        }

                        Cell cell10 = row.getCell(9);
                        if (cell10 != null) {
                            cell10.setCellType(CellType.STRING);
                            corpImportDetailEntity.setBatchNo(cell10.getStringCellValue());
                        }

                        Cell cell11 = row.getCell(10);
                        if (cell11 != null) {
                            cell11.setCellType(CellType.STRING);
                            corpImportDetailEntity.setProductDate(cell11.getStringCellValue());
                        }

                        Cell cell12 = row.getCell(11);
                        if (cell12 != null) {
                            cell12.setCellType(CellType.STRING);
                            corpImportDetailEntity.setExpireDate(cell12.getStringCellValue());
                        }

                        Cell cell13 = row.getCell(12);
                        if (cell13 != null) {
                            cell13.setCellType(CellType.STRING);
                            String count = cell13.getStringCellValue();
                            if (count != null && !"".equals(count)) {
                                corpImportDetailEntity.setCount(Integer.parseInt(count));
                            }
                        }
                        Cell cell14 = row.getCell(13);
                        if (cell14 != null) {
                            cell14.setCellType(CellType.STRING);
                            String count = cell14.getStringCellValue();
                            if (count != null && !"".equals(count)) {
                                corpImportDetailEntity.setReCount(Integer.parseInt(count));
                            }
                        }
                        Cell cell15 = row.getCell(14);
                        if (cell15 != null) {
                            cell15.setCellType(CellType.STRING);
                            corpImportDetailEntity.setOriginType(cell15.getStringCellValue());
                        }


                        corpImportDetailEntity.setThirdSysFk(thirdSys);
                        corpImportDetailEntity.setUpdateTime(new Date(System.currentTimeMillis()));
                        corpImportDetailEntities.add(corpImportDetailEntity);
                    }
                }
                workbook.close();
                thrOrderImportLogEntity.setDatas(corpImportDetailEntities);
//                new UdiwmsClient(udiwmsIp).postOrderDetail(thrOrderImportLogEntity);
                udiInfoUploadService.postOrders(thrOrderImportLogEntity);
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return ResultVOUtils.success("文件解析成功，正在上传，请稍后刷新查看");
    }

    public boolean filterEmpty(Row row) {

        if (row.getCell(0) != null) {
            row.getCell(0).setCellType(CellType.STRING);
        }
        if (row.getCell(1) != null) {
            row.getCell(1).setCellType(CellType.STRING);
        }
        if (row.getCell(2) != null) {
            row.getCell(2).setCellType(CellType.STRING);
        }
        if (row.getCell(3) != null) {
            row.getCell(3).setCellType(CellType.STRING);
        }
        if (row.getCell(4) != null) {
            row.getCell(4).setCellType(CellType.STRING);
        }
        if (row.getCell(5) != null) {
            row.getCell(5).setCellType(CellType.STRING);
        }
        if (row.getCell(6) != null) {
            row.getCell(6).setCellType(CellType.STRING);
        }
        if ((row.getCell(0) == null && row.getCell(1) == null && row.getCell(2) == null
                && row.getCell(3) == null && row.getCell(4) == null && row.getCell(5) == null && row.getCell(6) == null) ||
                (
                        (row.getCell(0) != null && row.getCell(1) != null && row.getCell(2) != null
                                && row.getCell(3) != null && row.getCell(4) != null && row.getCell(5) != null && row.getCell(6) != null) &&
                                ("".equals(row.getCell(0).getStringCellValue())
                                        && "".equals(row.getCell(1).getStringCellValue())
                                        && "".equals(row.getCell(2).getStringCellValue())
                                        && "".equals(row.getCell(3).getStringCellValue())
                                        && "".equals(row.getCell(4).getStringCellValue())
                                        && "".equals(row.getCell(5).getStringCellValue())
                                        && "".equals(row.getCell(6).getStringCellValue()))
                )) {
            return true;
        }
        return false;
    }
}
