package com.glxp.mipsdl.admin.client.file;

import com.glxp.mipsdl.admin.client.BaseFileClient;
import com.glxp.mipsdl.admin.entity.ygudplat.DeliCorpEntity;
import com.glxp.mipsdl.admin.entity.ygudplat.UdplatGoodsEntity;
import com.glxp.mipsdl.admin.req.system.PostThrCorpRequest;
import com.glxp.mipsdl.admin.req.system.PostThrProductsRequest;
import com.glxp.mipsdl.admin.res.system.UdiwmsProductInfoResponse;
import com.glxp.mipsdl.admin.res.system.UdiwmsUnitResponse;
import com.glxp.mipsdl.admin.thread.system.UdiInfoUploadService;
import com.glxp.mipsdl.admin.util.FastJsonUtils;
import com.glxp.mipsdl.admin.util.FileUtils;
import com.glxp.mipsdl.common.res.BaseResponse;
import com.glxp.mipsdl.common.util.ResultVOUtils;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;

/**
 * 阳光采购平台标准规范
 */
@Service
public class YGUdplatFileClient implements BaseFileClient {

    @Resource
    UdiInfoUploadService udiInfoUploadService;

    @Override
    public BaseResponse uploadPi(List<MultipartFile> files, String thirdSys) {
        for (int i = 0; i < files.size(); i++) {
            MultipartFile file = files.get(i);
            if (file.isEmpty()) {
                return ResultVOUtils.error(500, "上传第" + (i++) + "个文件失败");
            }
            try {
                InputStream inputStream = file.getInputStream();
                String json = FileUtils.readStream(inputStream);
                List<UdplatGoodsEntity> deliCorpEntities = FastJsonUtils.getJsonToList(json, UdplatGoodsEntity.class);
                List<UdiwmsProductInfoResponse> udiwmsProductInfoResponses = new ArrayList<>();
                if (deliCorpEntities != null && deliCorpEntities.size() > 0) {
                    for (UdplatGoodsEntity deliCorpEntity : deliCorpEntities) {
                        UdiwmsProductInfoResponse udiwmsProductInfoResponse = new UdiwmsProductInfoResponse();
                        udiwmsProductInfoResponse.setName(deliCorpEntity.getProductName());
                        udiwmsProductInfoResponse.setCode(deliCorpEntity.getProjectGoodsCode());
                        udiwmsProductInfoResponse.setSupName(deliCorpEntity.getDistributorName());
                        udiwmsProductInfoResponse.setManufactory(deliCorpEntity.getManufactureName());
                        udiwmsProductInfoResponse.setRegisterNo(deliCorpEntity.getRegNum());
                        udiwmsProductInfoResponse.setSpec(deliCorpEntity.getSpec());
                        udiwmsProductInfoResponse.setMeasname(deliCorpEntity.getPriceUnitText());
                        udiwmsProductInfoResponses.add(udiwmsProductInfoResponse);
                    }
                }
                PostThrProductsRequest postThrProductsRequest = new PostThrProductsRequest();
                postThrProductsRequest.setDatas(udiwmsProductInfoResponses);
                postThrProductsRequest.setUploadType("文件导入");
                postThrProductsRequest.setThirdSys(thirdSys);
                udiInfoUploadService.postProducts(postThrProductsRequest);
            } catch (IOException e) {
                e.printStackTrace();
                return ResultVOUtils.error(500, "文件格式错误！");
            }
        }
        return ResultVOUtils.success("文件解析成功，正在上传，请稍后刷新查看");
    }

    @Override
    public BaseResponse uploadCorps(List<MultipartFile> files, String thirdSys) {

        for (int i = 0; i < files.size(); i++) {
            MultipartFile file = files.get(i);
            if (file.isEmpty()) {
                return ResultVOUtils.error(500, "上传第" + (i++) + "个文件失败");
            }
            try {
                InputStream inputStream = file.getInputStream();
                String json = FileUtils.readStream(inputStream);
                List<DeliCorpEntity> deliCorpEntities = FastJsonUtils.getJsonToList(json, DeliCorpEntity.class);
                List<UdiwmsUnitResponse> udiwmsProductInfoResponses = new ArrayList<>();
                if (deliCorpEntities != null && deliCorpEntities.size() > 0) {
                    for (DeliCorpEntity deliCorpEntity : deliCorpEntities) {
                        UdiwmsUnitResponse udiwmsProductInfoResponse = new UdiwmsUnitResponse();
                        udiwmsProductInfoResponse.setUnitId(deliCorpEntity.getDistributorId());
                        udiwmsProductInfoResponse.setName(deliCorpEntity.getDistributorName());
                        udiwmsProductInfoResponses.add(udiwmsProductInfoResponse);
                    }
                }
                PostThrCorpRequest postThrProductsRequest = new PostThrCorpRequest();
                postThrProductsRequest.setCorps(udiwmsProductInfoResponses);
                postThrProductsRequest.setThirdSys(thirdSys);
                udiInfoUploadService.postCorps(postThrProductsRequest);
            } catch (IOException e) {
                e.printStackTrace();
                return ResultVOUtils.error(500, "文件格式错误！");
            }
        }
        return ResultVOUtils.success("文件解析成功，正在上传，请稍后刷新查看");

    }

    @Override
    public BaseResponse uploadInvPi(List<MultipartFile> files, String thirdSys) {
        return ResultVOUtils.error(500, "暂不支持库存产品信息上传！");
    }

    @Override
    public BaseResponse uploadOrders(List<MultipartFile> files, String thirdSys) {
        return ResultVOUtils.error(500, "暂不支持业务单据上传上传！");
    }
}
