package com.glxp.mipsdl.admin.client.file;

import com.glxp.mipsdl.admin.client.BaseFileClient;
import com.glxp.mipsdl.admin.entity.zy.ZyCorpEntity;
import com.glxp.mipsdl.admin.entity.zy.ZyProductEntity;
import com.glxp.mipsdl.admin.req.system.PostThrCorpRequest;
import com.glxp.mipsdl.admin.req.system.PostThrProductsRequest;
import com.glxp.mipsdl.admin.res.system.UdiwmsProductInfoResponse;
import com.glxp.mipsdl.admin.res.system.UdiwmsUnitResponse;
import com.glxp.mipsdl.admin.thread.system.UdiInfoUploadService;
import com.glxp.mipsdl.common.res.BaseResponse;
import com.glxp.mipsdl.common.util.ExcelUtil;
import com.glxp.mipsdl.common.util.ResultVOUtils;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.Row;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;

/**
 * 智业V1文件规范（漳州诏安医院）
 */
@Service
public class ZyV1FileClient implements BaseFileClient {

    Logger logger = LoggerFactory.getLogger(ZyV1FileClient.class);
    @Resource
    UdiInfoUploadService udiInfoUploadService;

    @Override
    public BaseResponse uploadPi(List<MultipartFile> files, String thirdSys) {


        for (int i = 0; i < files.size(); i++) {
            MultipartFile file = files.get(i);
            if (file.isEmpty()) {
                return ResultVOUtils.error(500, "上传第" + (i++) + "个文件失败");
            }
            try {
                InputStream inputStream = file.getInputStream();
                ExcelUtil<ZyProductEntity> util = new ExcelUtil(ZyProductEntity.class);
                List<ZyProductEntity> zyProductEntities = util.importExcel(inputStream);
                List<UdiwmsProductInfoResponse> udiwmsProductInfoResponses = new ArrayList<>();
                for (ZyProductEntity zyProductEntity : zyProductEntities) {
                    UdiwmsProductInfoResponse udiwmsProductInfoResponse = new UdiwmsProductInfoResponse();
                    BeanUtils.copyProperties(zyProductEntity, udiwmsProductInfoResponse);
                    udiwmsProductInfoResponses.add(udiwmsProductInfoResponse);
                }
                PostThrProductsRequest postThrProductsRequest = new PostThrProductsRequest();
                postThrProductsRequest.setDatas(udiwmsProductInfoResponses);
                postThrProductsRequest.setUploadType("文件导入");
                postThrProductsRequest.setThirdSys(thirdSys);
                udiInfoUploadService.postProducts(postThrProductsRequest);
                logger.error("上传完" + System.currentTimeMillis());
            } catch (IOException e) {
                e.printStackTrace();
                return ResultVOUtils.error(500, "数据异常");
            } catch (Exception e) {
                e.printStackTrace();
                return ResultVOUtils.error(500, "数据异常");
            }
        }
        return ResultVOUtils.success("文件解析成功，正在上传，请稍后刷新查看");
    }

    @Override
    public BaseResponse uploadCorps(List<MultipartFile> files, String thirdSys) {

        for (int i = 0; i < files.size(); i++) {
            MultipartFile file = files.get(i);
            if (file.isEmpty()) {
                return ResultVOUtils.error(500, "上传第" + (i++) + "个文件失败");
            }
            List<UdiwmsUnitResponse> udiwmsUnitResponses = new ArrayList<>();
            try {
                InputStream inputStream = file.getInputStream();
                ExcelUtil<ZyCorpEntity> util = new ExcelUtil(ZyCorpEntity.class);
                List<ZyCorpEntity> zyCorpEntities = util.importExcel(inputStream);
                for (ZyCorpEntity zyCorpEntity : zyCorpEntities) {
                    UdiwmsUnitResponse udiwmsUnitResponse = new UdiwmsUnitResponse();
                    udiwmsUnitResponse.setName(zyCorpEntity.getCorpName());
                    udiwmsUnitResponse.setUnitId(zyCorpEntity.getCorpCode());
                    udiwmsUnitResponses.add(udiwmsUnitResponse);
                }
                PostThrCorpRequest postThrProductsRequest = new PostThrCorpRequest();
                postThrProductsRequest.setCorps(udiwmsUnitResponses);
                postThrProductsRequest.setThirdSys(thirdSys);
                udiInfoUploadService.postCorps(postThrProductsRequest);
            } catch (IOException e) {
                e.printStackTrace();
                return ResultVOUtils.error(500, "数据异常");
            } catch (Exception e) {
                e.printStackTrace();
                return ResultVOUtils.error(500, "数据异常");
            }
        }
        return ResultVOUtils.success("文件解析成功，正在上传，请稍后刷新查看");
    }

    @Override
    public BaseResponse uploadInvPi(List<MultipartFile> files, String thirdSys) {
        return ResultVOUtils.error(500, "暂不支持库存产品信息上传！");
    }

    @Override
    public BaseResponse uploadOrders(List<MultipartFile> files, String thirdSys) {
        return ResultVOUtils.error(500, "暂不支持业务单据上传！");
    }


    public boolean filterEmpty(Row row) {

        if (row.getCell(0) != null) {
            row.getCell(0).setCellType(CellType.STRING);
        }
        if (row.getCell(1) != null) {
            row.getCell(1).setCellType(CellType.STRING);
        }
        if (row.getCell(2) != null) {
            row.getCell(2).setCellType(CellType.STRING);
        }
        if (row.getCell(3) != null) {
            row.getCell(3).setCellType(CellType.STRING);
        }
        if (row.getCell(4) != null) {
            row.getCell(4).setCellType(CellType.STRING);
        }
        if (row.getCell(5) != null) {
            row.getCell(5).setCellType(CellType.STRING);
        }
        if (row.getCell(6) != null) {
            row.getCell(6).setCellType(CellType.STRING);
        }
        if ((row.getCell(0) == null && row.getCell(1) == null && row.getCell(2) == null
                && row.getCell(3) == null && row.getCell(4) == null && row.getCell(5) == null && row.getCell(6) == null) ||
                (
                        (row.getCell(0) != null && row.getCell(1) != null && row.getCell(2) != null
                                && row.getCell(3) != null && row.getCell(4) != null && row.getCell(5) != null && row.getCell(6) != null) &&
                                ("".equals(row.getCell(0).getStringCellValue())
                                        && "".equals(row.getCell(1).getStringCellValue())
                                        && "".equals(row.getCell(2).getStringCellValue())
                                        && "".equals(row.getCell(3).getStringCellValue())
                                        && "".equals(row.getCell(4).getStringCellValue())
                                        && "".equals(row.getCell(5).getStringCellValue())
                                        && "".equals(row.getCell(6).getStringCellValue()))
                )) {
            return true;
        }
        return false;
    }

}
