package com.glxp.mipsdl.admin.client.http;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.glxp.mipsdl.admin.config.ThirdSysConfig;
import com.glxp.mipsdl.admin.dao.phxyy.BasicThirdSysDetailDao;
import com.glxp.mipsdl.admin.entity.phxyy.BasicThirdSysBusApiEntity;
import com.glxp.mipsdl.admin.entity.phxyy.BasicThirdSysDetailEntity;
import com.glxp.mipsdl.admin.req.UdiwmsOnhandRequest;
import com.glxp.mipsdl.admin.req.UdiwmsOrderRequest;
import com.glxp.mipsdl.admin.req.phxyy.*;
import com.glxp.mipsdl.admin.res.phxyy.BussinessOriginTypeResponse;
import com.glxp.mipsdl.admin.service.phxyy.BasicThirdSysBusApiService;
import com.glxp.mipsdl.admin.service.phxyy.BussinessOriginTypeService;
import com.glxp.mipsdl.admin.util.HttpClient;
import com.glxp.mipsdl.common.res.BaseResponse;
import com.glxp.mipsdl.common.util.ResultVOUtils;
import org.springframework.http.HttpHeaders;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * 平和县医院对接
 */
@Service
public class PhxyyClient {

    @Resource
    private ThirdSysConfig thirdSysConfig;
    @Resource
    private HttpClient httpClient;

    public HttpHeaders getHeaders() {
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type", "application/json");
        headers.add("api_key", thirdSysConfig.getThirdSysConfig().getApikey());
        headers.add("secret_key", thirdSysConfig.getThirdSysConfig().getSecretkey());
        return headers;
    }


    String[] getHeaderArray() {
        List<String> headArray = new ArrayList<>();
        headArray.add("Content-Type");
        headArray.add("application/json");
        if (StrUtil.isNotEmpty(thirdSysConfig.getThirdSysConfig().getApikey())) {
            headArray.add("api_key");
            headArray.add(thirdSysConfig.getThirdSysConfig().getApikey());
        }
        if (StrUtil.isNotEmpty(thirdSysConfig.getThirdSysConfig().getSecretkey())) {
            headArray.add("secret_key");
            headArray.add(thirdSysConfig.getThirdSysConfig().getSecretkey());
        }
        String[] strArray = new String[headArray.size()];
        headArray.toArray(strArray);
        return strArray;
    }

    @Resource
    private BasicThirdSysBusApiService basicThirdSysBusApiService;
    @Resource
    private BussinessOriginTypeService bussinessOriginTypeService;
    @Resource
    private BasicThirdSysDetailDao basicThirdSysDetailDao;


    public BaseResponse testConnect() {
        PhUnitRequest phUnitRequest = new PhUnitRequest();
        phUnitRequest.setPage(1);
        phUnitRequest.setLimit(1);
        BaseResponse baseResponse = getUnit(phUnitRequest);
        if (baseResponse.getCode() == 20000) {
            return ResultVOUtils.success("连接成功！");
        } else {
            return ResultVOUtils.error(500, "连接失败");
        }
    }


    public BaseResponse getUnit(PhUnitRequest unitRequest) {
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailDao.selectByKey("corpUrl", thirdSysConfig.getThirdSysConfig().getThirdId());
        String response = httpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysDetailEntity.getValue(), unitRequest, getHeaderArray());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    public BaseResponse getProducts(PhProductRequest udiwmsProductRequest) {
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailDao.selectByKey("piQueryUrl", thirdSysConfig.getThirdSysConfig().getThirdId());
        String response = httpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysDetailEntity.getValue(), udiwmsProductRequest, getHeaderArray());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    public BaseResponse getOrderTypes(PhBusTypeRequest udiwmsBusTypeRequest) {
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailDao.selectByKey("busTypeQueryUrl", thirdSysConfig.getThirdSysConfig().getThirdId());
        String response = httpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysDetailEntity.getValue(), udiwmsBusTypeRequest, getHeaderArray());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    public BaseResponse getOrders(UdiwmsOrderRequest udiwmsOrderRequest) {
        if (StrUtil.isEmpty(udiwmsOrderRequest.getBillType())) {
            return ResultVOUtils.error(500, "单据类型不能未空");
        }
        if (StrUtil.isEmpty(udiwmsOrderRequest.getThirdSys())) {
            return ResultVOUtils.error(500, "第三方系统ID不能为空");
        }
        BussinessOriginTypeResponse bussinessOriginTypeResponse = bussinessOriginTypeService.findByKey(udiwmsOrderRequest.getBillType(), thirdSysConfig.getThirdSysConfig().getThirdId());
        udiwmsOrderRequest.setBillType(bussinessOriginTypeResponse.getThirdAction());
        BasicThirdSysBusApiEntity basicThirdSysBusApiEntity = basicThirdSysBusApiService.selectByKey(bussinessOriginTypeResponse.getThirdAction(), bussinessOriginTypeResponse.getThirdSys(), 1);
        String response = httpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysBusApiEntity.getUrl(), udiwmsOrderRequest, getHeaderArray());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    public BaseResponse submitOrders(PhOrderRequest udiwmsOrderRequest) {
        if (StrUtil.isEmpty(udiwmsOrderRequest.getBillType())) {
            return ResultVOUtils.error(500, "单据类型不能未空");
        }
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailDao.selectByKey("orderSubmitUrl", thirdSysConfig.getThirdSysConfig().getThirdId());
        String response = httpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysDetailEntity.getValue(), udiwmsOrderRequest, getHeaderArray());





        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    public BaseResponse getInvProducts(UdiwmsOnhandRequest udiwmsOnhandRequest) {
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailDao.selectByKey("invPiUrl", thirdSysConfig.getThirdSysConfig().getThirdId());
        String response = httpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysDetailEntity.getValue(), udiwmsOnhandRequest, getHeaderArray());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    public BaseResponse getWarehouse(PhWarehouseRequest udiwmsWarehouseRequest) {
        BasicThirdSysDetailEntity basicThirdSysDetailEntity = basicThirdSysDetailDao.selectByKey("warehouseQueryUrl", thirdSysConfig.getThirdSysConfig().getThirdId());
        String response = httpClient.postJson(thirdSysConfig.getThirdSysConfig().getThirdSysUrl() + basicThirdSysDetailEntity.getValue(), udiwmsWarehouseRequest, getHeaderArray());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }
}
