package com.glxp.mipsdl.admin.client.http;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.glxp.mipsdl.admin.entity.test.TestOrderResponse;
import com.glxp.mipsdl.admin.req.*;
import com.glxp.mipsdl.admin.req.phxyy.PhUnitRequest;
import com.glxp.mipsdl.admin.res.system.*;
import com.glxp.mipsdl.admin.util.CustomUtil;
import com.glxp.mipsdl.admin.util.FileUtils;
import com.glxp.mipsdl.common.res.BaseResponse;
import com.glxp.mipsdl.common.util.ResultVOUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 测试客户端，用于模拟测试数据
 */
@Slf4j
@Service
public class TestClient {


    /**
     * 查询往来单位信息
     *
     * @param testUnitRequest
     * @return
     */
    public BaseResponse getUnit(PhUnitRequest testUnitRequest) {


        String data = FileUtils.readFileAll("E:\\第三方测试数据\\第三方往来单位测试数据.json");
        BaseResponse<PageSimpleResponse<UdiwmsUnitResponse>> udiDlDeviceResponse =
                JSONObject.parseObject(data, new TypeReference<BaseResponse<PageSimpleResponse<UdiwmsUnitResponse>>>() {
                });
        return udiDlDeviceResponse;
    }

    /**
     * 查询产品信息
     *
     * @param udiwmsProductRequest
     * @return
     */
    public BaseResponse getProducuts(UdiwmsProductRequest udiwmsProductRequest) {

        String data = FileUtils.readFileAll("E:\\第三方测试数据\\第三方产品信息测试数据.json");
        BaseResponse<PageSimpleResponse<UdiwmsProductInfoResponse>> udiDlDeviceResponse =
                JSONObject.parseObject(data, new TypeReference<BaseResponse<PageSimpleResponse<UdiwmsProductInfoResponse>>>() {
                });
        return udiDlDeviceResponse;

    }

    /**
     * 获取订单信息接口
     *
     * @param udiwmsOrderRequest
     * @return
     */
    public BaseResponse getOrders(UdiwmsOrderRequest udiwmsOrderRequest) {
        if (null == udiwmsOrderRequest || StrUtil.isBlank(udiwmsOrderRequest.getThirdSys())) {
            return ResultVOUtils.error(500, "第三方系统ID不能为空");
        }
        UdiwmsOrderResponse udiwmsOrderResponse = new UdiwmsOrderResponse();
        udiwmsOrderResponse.setBillNo("SP2022031376813");
        udiwmsOrderResponse.setStartDate("2022-03-13");
        udiwmsOrderResponse.setStartDate("2022-03-20");
        udiwmsOrderResponse.setBillFlag("单据状态");
        udiwmsOrderResponse.setBillType("ST54467264148");
        udiwmsOrderResponse.setBilldate("2022-03-13");
        udiwmsOrderResponse.setCreateUser("沈先生");
        udiwmsOrderResponse.setReviewUser("沈先生");
        udiwmsOrderResponse.setAddress("福建省厦门市集美区");
        udiwmsOrderResponse.setLinkMan("沈先生");
        udiwmsOrderResponse.setLinkTel("13306961860");
        List<UdiwmsOrderResponse.SubErpOrder> subErpOrders = new ArrayList<>();
        for (int i = 0; i < 3; i++) {
            UdiwmsOrderResponse.SubErpOrder subErpOrder = new UdiwmsOrderResponse.SubErpOrder();
            subErpOrder.setDetailId(CustomUtil.getId());
            subErpOrder.setCorpName("福建片仔癀诊断技术有限公司");
            subErpOrder.setBatchNo(CustomUtil.getUUId());
            subErpOrder.setProductDate(DateUtil.formatDate(DateUtil.yesterday()));
            subErpOrder.setExpireDate(DateUtil.formatDate(DateUtil.tomorrow()));
            subErpOrder.setCount(10);
            subErpOrder.setPrice(BigDecimal.valueOf(1000, 2));
            subErpOrder.setProductId("6555");
            subErpOrders.add(subErpOrder);
        }

        udiwmsOrderResponse.setDetailList(subErpOrders);
        return ResultVOUtils.success(udiwmsOrderResponse);
    }


    public BaseResponse getBusType(UdiwmsBusTypeRequest udiwmsBusTypeRequest) {


        if (null == udiwmsBusTypeRequest) {
            return ResultVOUtils.error(500, "参数不能未空");
        }
        String data = FileUtils.readFileAll("E:\\第三方测试数据\\第三方单据类型测试数据.json");
        BaseResponse<PageSimpleResponse<UdiwmsBusTypeResponse>> udiDlDeviceResponse =
                JSONObject.parseObject(data, new TypeReference<BaseResponse<PageSimpleResponse<UdiwmsBusTypeResponse>>>() {
                });
        return udiDlDeviceResponse;
    }

    /**
     * 新增订单
     *
     * @param udiwmsOrderRequest
     * @return
     */
    public BaseResponse addOrders(UdiwmsOrderRequest udiwmsOrderRequest) {
//        Map<String, Object> verifyResult = verifyOrderParams(udiwmsOrderRequest);
//        boolean flag = (boolean) verifyResult.get("flag");
//        if (!flag) {
//            return ResultVOUtils.error(500, verifyResult.get("msg").toString());
//        }
        TestOrderResponse udiwmsOrderResponse = new TestOrderResponse();
        udiwmsOrderResponse.setThirdBillNo(CustomUtil.getId());
        return ResultVOUtils.success(udiwmsOrderResponse);
    }

    /**
     * 校验单据参数
     *
     * @param udiwmsOrderRequest
     * @return
     */
    private Map<String, Object> verifyOrderParams(UdiwmsOrderRequest udiwmsOrderRequest) {
        boolean flag = true;
        String msg = "";
        if (null == udiwmsOrderRequest) {
            flag = false;
            msg = "单据数据不能为空";
        } else if (StrUtil.isBlank(udiwmsOrderRequest.getThirdSys())) {
            flag = false;
            msg = "第三方系统ID不能为空";
        } else if (StrUtil.isBlank(udiwmsOrderRequest.getBillDate()) || StrUtil.isBlank(udiwmsOrderRequest.getBillFlag()) || StrUtil.isBlank(udiwmsOrderRequest.getCorpName())
                || StrUtil.isBlank(udiwmsOrderRequest.getCorpId()) || StrUtil.isBlank(udiwmsOrderRequest.getBillType()) || StrUtil.isBlank(udiwmsOrderRequest.getStatus())
        ) {// || StrUtil.isBlank(udiwmsOrderRequest.getStatus()) || CollUtil.isEmpty(udiwmsOrderRequest.getItem())
            flag = false;
            msg = "订单关键参数缺失或错误";
        } else {
            List<UdiwmsOrderDetail> items = udiwmsOrderRequest.getItem();
            for (UdiwmsOrderDetail item : items) {
                if (StrUtil.isBlank(item.getProductId()) || StrUtil.isBlank(item.getProductName()) || null == item.getPrice()
                        || null == item.getCount() || 0 >= item.getPrice().compareTo(BigDecimal.ZERO) || 0 >= item.getCount()
                        || StrUtil.isBlank(item.getProductDate()) || StrUtil.isBlank(item.getStandard())) {
                    flag = false;
                    msg = "单据详情数据缺失";
                    break;
                }
            }
        }
        Map<String, Object> map = new HashMap<>(2);
        map.put("flag", flag);
        map.put("msg", msg);
        return map;
    }

    /**
     * 修改单据信息
     *
     * @param udiwmsOrderRequest
     * @return
     */
    public BaseResponse editOrder(UdiwmsOrderRequest udiwmsOrderRequest) {
        Map<String, Object> verifyResult = verifyOrderParams(udiwmsOrderRequest);
        boolean flag = (boolean) verifyResult.get("flag");
        if (!flag) {
            return ResultVOUtils.error(500, verifyResult.get("msg").toString());
        }
        if (StrUtil.isBlank(udiwmsOrderRequest.getBillNo())) {
            return ResultVOUtils.error(500, "单据号不能为空");
        }
        return ResultVOUtils.success(CustomUtil.getId());
    }

    /**
     * 查询库存产品信息
     *
     * @param udiwmsOnhandRequest
     * @return
     */
    public BaseResponse getEnvProduct(UdiwmsOnhandRequest udiwmsOnhandRequest) {
        if (null == udiwmsOnhandRequest || StrUtil.isBlank(udiwmsOnhandRequest.getThirdSys())) {
            return ResultVOUtils.error(500, "第三方系统ID不能为空");
        }
        List<UdiwmsInvProductResponse> list = new ArrayList<>();
        for (int i = 0; i < 3; i++) {
            UdiwmsInvProductResponse response = new UdiwmsInvProductResponse();
            response.setBatchNo("批次号");
            response.setInventoryCode("1");
            response.setInventoryName("总库");
            response.setWarehouseCode("1001");
            response.setWarehouseName("货位1");
            response.setProductDate(DateUtil.formatDate(DateUtil.yesterday()));
            response.setExpireDate(DateUtil.formatDate(DateUtil.tomorrow()));
            response.setProductName("下肢直型锁定钢板");
            response.setProductId("6555");
            response.setStandard("12孔");
            response.setRegisterNo("20153461024");
            response.setCount(10);
            response.setManufactory("江苏艾迪尔");
            response.setSupId("2001");
            response.setSupName("南昌必理商贸有限公司");
            list.add(response);
        }
        return ResultVOUtils.success(list);
    }

    public BaseResponse getWarehouse(UdiwmsWarehouseRequest udiwmsWarehouseRequest) {
        if (null == udiwmsWarehouseRequest || StrUtil.isBlank(udiwmsWarehouseRequest.getThirdSys())) {
            return ResultVOUtils.error(500, "第三方系统ID不能为空");
        }
        String data = FileUtils.readFileAll("E:\\第三方测试数据\\第三方仓库字段测试数据.json");
        BaseResponse<PageSimpleResponse<UdiwmsWarehouseResponse>> udiDlDeviceResponse =
                JSONObject.parseObject(data, new TypeReference<BaseResponse<PageSimpleResponse<UdiwmsWarehouseResponse>>>() {
                });
        return udiDlDeviceResponse;
    }
}
