package com.glxp.mipsdl.admin.client.http;

import com.glxp.mipsdl.admin.client.BaseHttpClient;
import com.glxp.mipsdl.admin.entity.yyu8v31.YyUcloudV31SetEntity;
import com.glxp.mipsdl.admin.entity.yyu8v31.ErpOrderEntity;
import com.glxp.mipsdl.admin.entity.yyu8v31.ErpStockEntity;
import com.glxp.mipsdl.admin.http.UBaseResponse;
import com.glxp.mipsdl.admin.http.UCloudBasicClient;
import com.glxp.mipsdl.admin.http.UCloudStockClient;
import com.glxp.mipsdl.admin.http.request.*;
import com.glxp.mipsdl.admin.http.response.*;
import com.glxp.mipsdl.admin.req.*;
import com.glxp.mipsdl.admin.res.system.*;
import com.glxp.mipsdl.admin.service.pzhzd.InvErpStockService;
import com.glxp.mipsdl.admin.service.pzhzd.YyUcloudV31SetService;
import com.glxp.mipsdl.admin.util.DateUtil;
import com.glxp.mipsdl.common.enums.ResultEnum;
import com.glxp.mipsdl.common.res.BaseResponse;
import com.glxp.mipsdl.common.util.ResultVOUtils;
import org.springframework.http.HttpHeaders;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 片仔癀诊断用友ERP
 */
@Service
public class YyUCloud31Client implements BaseHttpClient {


    @Resource
    YyUcloudV31SetService setService;

    @Resource
    InvErpStockService erpStockService;
    YyUcloudV31SetEntity setEntity;

    public HttpHeaders getNewHeads() {
        setEntity = setService.finSetUp();
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type", "application/json; charset=UTF-8");
        if (setEntity != null) {
            headers.add("system", setEntity.getSystemCode());
            headers.add("usercode", setEntity.getUserCode());
            headers.add("password", setEntity.getPasswd());
            headers.add("trantype", setEntity.getTransType());
        }
        return headers;
    }

    @Override
    public BaseResponse getUnit(UdiwmsUnitRequest testUnitRequest) {

        HttpHeaders headers = getNewHeads();
        UCustmandocRequest uCustmandocRequest = new UCustmandocRequest(testUnitRequest.getPage() + "", testUnitRequest.getLimit() + "");
        uCustmandocRequest.setCustshortname(testUnitRequest.getKey());
        uCustmandocRequest.setCustname(testUnitRequest.getName());
        uCustmandocRequest.setCustcode(testUnitRequest.getUnitId());
        uCustmandocRequest.setUnitcode(setEntity.getUnitCode());
        UBaseResponse<List<UCustmandocResponse>> response = new UCloudBasicClient(setEntity.getIpUrl(), headers).custmandocQuery(uCustmandocRequest);
        if (response != null) {
            List<UCustmandocResponse> uCustmandocResponses = response.getData().getDatas();
            if (uCustmandocResponses != null && !uCustmandocResponses.isEmpty()) {
                List<UdiwmsUnitResponse> custmandocResponses = new ArrayList<>();
                for (UCustmandocResponse queryResponse : uCustmandocResponses) {
                    UdiwmsUnitResponse custmandocResponse = new UdiwmsUnitResponse();
                    custmandocResponse.setAddr(queryResponse.getParentvo().getConaddr());
                    custmandocResponse.setUnitId(queryResponse.getParentvo().getCustcode());
                    custmandocResponse.setName(queryResponse.getParentvo().getCustname());
                    custmandocResponse.setSpell(queryResponse.getParentvo().getMnecode());
                    custmandocResponse.setMobile(queryResponse.getParentvo().getPhone1());
                    custmandocResponse.setContact(queryResponse.getParentvo().getLinkman1());
                    custmandocResponses.add(custmandocResponse);
                }
                PageSimpleResponse<UdiwmsUnitResponse> pageSimpleResponse = new PageSimpleResponse<>();
                pageSimpleResponse.setTotal((long) response.getData().getAllcount());
                pageSimpleResponse.setList(custmandocResponses);
                return ResultVOUtils.success(pageSimpleResponse);
            }
        }
        return ResultVOUtils.error(500, "数据查询失败");
    }

    @Override
    public BaseResponse getProducts(UdiwmsProductRequest udiwmsProductRequest) {
        HttpHeaders headers = getNewHeads();
        UInvmandocRequest uInvmandocRequest = new UInvmandocRequest();
        uInvmandocRequest.setUnitcode(setEntity.getUnitCode());
        uInvmandocRequest.setInvname(udiwmsProductRequest.getName());
        uInvmandocRequest.setInvcode(udiwmsProductRequest.getCode());
        uInvmandocRequest.setPage_size(udiwmsProductRequest.getLimit() + "");
        uInvmandocRequest.setPage_now(udiwmsProductRequest.getPage() + "");
        UBaseResponse<List<UInvmandocQueryResponse>> response =
                new UCloudBasicClient(setEntity.getIpUrl(), headers).invmandocQuery(uInvmandocRequest);
        if (response != null) {
            List<UInvmandocQueryResponse> uCustmandocResponses = response.getData().getDatas();
            if (uCustmandocResponses != null && !uCustmandocResponses.isEmpty()) {
                List<UdiwmsProductInfoResponse> custmandocResponses = new ArrayList<>();
                for (UInvmandocQueryResponse queryResponse : uCustmandocResponses) {
                    UdiwmsProductInfoResponse invmandocResponse = new UdiwmsProductInfoResponse();
                    invmandocResponse.setCode(queryResponse.getParentvo().getInvbasVo().getInvcode());
                    invmandocResponse.setName(queryResponse.getParentvo().getInvbasVo().getInvname());
                    invmandocResponse.setMeasname(queryResponse.getParentvo().getInvbasVo().getMeasname());
                    invmandocResponse.setSpec(queryResponse.getParentvo().getInvbasVo().getInvspec());
                    invmandocResponse.setRegisterNo(queryResponse.getParentvo().getInvbasVo().getInvtype());
                    invmandocResponse.setManufactory(queryResponse.getParentvo().getInvmanVo().getProdarea());
                    custmandocResponses.add(invmandocResponse);
                }
                PageSimpleResponse<UdiwmsProductInfoResponse> pageSimpleResponse = new PageSimpleResponse<>();
                pageSimpleResponse.setTotal((long) response.getData().getAllcount());
                pageSimpleResponse.setList(custmandocResponses);
                return ResultVOUtils.success(pageSimpleResponse);
            }
        }
        return ResultVOUtils.success(response);
    }

    @Override
    public BaseResponse getOrderTypes(UdiwmsBusTypeRequest udiwmsOrderRequest) {
        return null;
    }

    @Override
    public BaseResponse getOrders(UdiwmsOrderRequest udiwmsOrderRequest) {
        if (udiwmsOrderRequest.getAction() == null && udiwmsOrderRequest.getBillAction() == null) {
            return ResultVOUtils.error(500, "单据类型不能为空！");
        }
        if ("WareHouseIn".equals(udiwmsOrderRequest.getAction()) || udiwmsOrderRequest.getBillAction().equals("采购入库")
                || udiwmsOrderRequest.getBillAction().equals("退货出库")) {
            UPurchaseinRequest uPurchaseinRequest = new UPurchaseinRequest();
            uPurchaseinRequest.setDate_end(udiwmsOrderRequest.getEndDate());
            uPurchaseinRequest.setDate_begin(udiwmsOrderRequest.getStartDate());
            uPurchaseinRequest.setPage_now(udiwmsOrderRequest.getPage() + "");
            uPurchaseinRequest.setPage_size(udiwmsOrderRequest.getLimit() + "");
            // 3是已签字  2是未签字
            if ("0".equals(udiwmsOrderRequest.getBillFlag())) {
                uPurchaseinRequest.setFbillflag("2");
            } else if (("1").equals(udiwmsOrderRequest.getBillFlag())) {
                uPurchaseinRequest.setFbillflag("3");
            }
            uPurchaseinRequest.setBillcode(udiwmsOrderRequest.getBillNo());
            List<UdiwmsOrderResponse> udiwmsOrderResponses = getPurchasein(uPurchaseinRequest);
            if (udiwmsOrderResponses != null && udiwmsOrderResponses.size() > 0) {
                List<UdiwmsOrderResponse> returnsList = new ArrayList<>();
                if ("采购入库".equals(udiwmsOrderRequest.getBillAction())) {
                    for (int i = 0; i < udiwmsOrderResponses.size(); i++) {
                        if (udiwmsOrderResponses.get(i).getBillType().equals("采购入库")) {
                            returnsList.add(udiwmsOrderResponses.get(i));
                        }
                    }
                } else if ("退货出库".equals(udiwmsOrderRequest.getBillAction())) {
                    for (int i = 0; i < udiwmsOrderResponses.size(); i++) {
                        if (udiwmsOrderResponses.get(i).getBillType().equals("退货出库")) {
                            returnsList.add(udiwmsOrderResponses.get(i));
                        }
                    }
                } else if ("WareHouseIn".equals(udiwmsOrderRequest.getAction())) {
                    returnsList.addAll(udiwmsOrderResponses);
                }
                PageSimpleResponse<UdiwmsOrderResponse> pageSimpleResponse = new PageSimpleResponse<>();
                pageSimpleResponse.setTotal((long) returnsList.size());
                pageSimpleResponse.setList(returnsList);
                return ResultVOUtils.success(pageSimpleResponse);
            } else
                return ResultVOUtils.error(500, "未查询到数据");

        } else if (
                "WareHouseOut".equals(udiwmsOrderRequest.getAction()) ||
                        udiwmsOrderRequest.getBillAction().equals("销售出库") || udiwmsOrderRequest.getBillAction().equals("退货入库")) {

            USaleoutQueryRequest uSaleoutQueryRequest = new USaleoutQueryRequest();
            uSaleoutQueryRequest.setDate_end(udiwmsOrderRequest.getEndDate());
            uSaleoutQueryRequest.setDate_begin(udiwmsOrderRequest.getStartDate());
            uSaleoutQueryRequest.setPage_now(udiwmsOrderRequest.getPage() + "");
            uSaleoutQueryRequest.setPage_size(udiwmsOrderRequest.getLimit() + "");
            // 3是已签字  2是未签字
            if ("0".equals(udiwmsOrderRequest.getBillFlag())) {
                uSaleoutQueryRequest.setFbillflag("2");
            } else if (("1").equals(udiwmsOrderRequest.getBillFlag())) {
                uSaleoutQueryRequest.setFbillflag("3");
            }
            uSaleoutQueryRequest.setBillcode(udiwmsOrderRequest.getBillNo());

            List<UdiwmsOrderResponse> udiwmsOrderResponses = getSaleout(uSaleoutQueryRequest);
            if (udiwmsOrderResponses != null && udiwmsOrderResponses.size() > 0) {
                List<UdiwmsOrderResponse> returnsList = new ArrayList<>();
                if ("销售出库".equals(udiwmsOrderRequest.getBillAction())) {
                    for (int i = 0; i < udiwmsOrderResponses.size(); i++) {
                        if (udiwmsOrderResponses.get(i).getBillType().equals("销售出库")) {
                            returnsList.add(udiwmsOrderResponses.get(i));
                        }
                    }
                } else if ("退货入库".equals(udiwmsOrderRequest.getBillAction())) {
                    for (int i = 0; i < udiwmsOrderResponses.size(); i++) {
                        if (udiwmsOrderResponses.get(i).getBillType().equals("退货入库")) {
                            returnsList.add(udiwmsOrderResponses.get(i));
                        }
                    }
                } else if ("WareHouseIn".equals(udiwmsOrderRequest.getAction())) {
                    returnsList.addAll(udiwmsOrderResponses);
                }
                PageSimpleResponse<UdiwmsOrderResponse> pageSimpleResponse = new PageSimpleResponse<>();
                pageSimpleResponse.setTotal((long) returnsList.size());
                pageSimpleResponse.setList(returnsList);
                return ResultVOUtils.success(pageSimpleResponse);
            } else
                return ResultVOUtils.error(500, "未查询到数据");
        } else {
            return ResultVOUtils.error(500, "单据类型错误！");
        }
    }

    @Override
    public BaseResponse submitOrders(UdiwmsOrderRequest udiwmsOrderRequest) {
        return null;
    }

    @Override
    public BaseResponse getInvProducts(UdiwmsOnhandRequest udiwmsOnhandRequest) {

        HttpHeaders headers = getNewHeads();
        if (udiwmsOnhandRequest.getPage() > 1) {
            return ResultVOUtils.error(500, "超出最大数");
        }
        UOnhandQueryRequest onhandQueryRequest = new UOnhandQueryRequest();
        if (udiwmsOnhandRequest.getInventoryCode() != null) {
            onhandQueryRequest.setInventory(udiwmsOnhandRequest.getInventoryCode());
        } else if (udiwmsOnhandRequest.getInventoryCodes() != null) {
            onhandQueryRequest.setInventorys(udiwmsOnhandRequest.getInventoryCodes());
        }
        onhandQueryRequest.setPage_size(udiwmsOnhandRequest.getLimit() + "");
        onhandQueryRequest.setPage_now(udiwmsOnhandRequest.getPage() + "");
        onhandQueryRequest.setBatchcode(udiwmsOnhandRequest.getBatchNo());
        onhandQueryRequest.setWarehouse(udiwmsOnhandRequest.getWarehouseCode());
        onhandQueryRequest.setCorp(setEntity.getUnitCode());
        onhandQueryRequest.setCalbody(setEntity.getUnitCode());
        UBaseResponse<List<UOnhandQueryResponse>> response = new UCloudStockClient(setEntity.getIpUrl(), headers).onhandQuery(onhandQueryRequest);
        if (response != null) {
            List<UOnhandQueryResponse> uOnhandQueryResponses;
            uOnhandQueryResponses = response.getData().getDatas();
            if (uOnhandQueryResponses != null && uOnhandQueryResponses.size() > 0) {
                List<UdiwmsInvProductResponse> udiwmsOnhandResponses = new ArrayList<>();
                for (UOnhandQueryResponse onhandQueryResponse : uOnhandQueryResponses) {
                    UdiwmsInvProductResponse udiwmsOnhandResponse = new UdiwmsInvProductResponse();
                    udiwmsOnhandResponse.setName(onhandQueryResponse.getCinventory_name());
                    udiwmsOnhandResponse.setBatchNo(onhandQueryResponse.getVbatchcode());
                    udiwmsOnhandResponse.setCode(onhandQueryResponse.getCinventory_code());
                    udiwmsOnhandResponse.setCount(onhandQueryResponse.getNnum());
                    udiwmsOnhandResponse.setSpec(onhandQueryResponse.getInvspec());
                    udiwmsOnhandResponse.setRegisterCertNo(onhandQueryResponse.getInvtype());
                    udiwmsOnhandResponse.setWarehouseName(onhandQueryResponse.getCwarehouse_name());
                    udiwmsOnhandResponse.setWarehouseCode(onhandQueryResponse.getCwarehouse_code());
                    ErpStockEntity erpStockEntity = erpStockService.findByCode(udiwmsOnhandResponse.getCode(), udiwmsOnhandResponse.getBatchNo());
                    if (erpStockEntity != null) {
                        udiwmsOnhandResponse.setExpirationDate(erpStockEntity.getExpirationDate());
                        udiwmsOnhandResponse.setManufacturingDate(erpStockEntity.getManufacturingDate());
                    }
                    udiwmsOnhandResponses.add(udiwmsOnhandResponse);
                }
                PageSimpleResponse<UdiwmsInvProductResponse> pageSimpleResponse = new PageSimpleResponse<>();
                pageSimpleResponse.setTotal(udiwmsOnhandResponses.size() + 0L);
                pageSimpleResponse.setList(udiwmsOnhandResponses);
                return ResultVOUtils.success(pageSimpleResponse);
            }

        }
        return ResultVOUtils.success(response);
    }

    public BaseResponse modifyBill(UdiwmsPostBillRequest udiwmsPostBillRequest) {
        Map<String, List<ErpOrderEntity>> postMap = udiwmsPostBillRequest.getPostMap();
        if (udiwmsPostBillRequest.getModifyType() != null && "sign".equals(udiwmsPostBillRequest.getModifyType())) {
            USignRequest signRequest = new USignRequest();
            signRequest.setBillcode(udiwmsPostBillRequest.getBillNo());
            signRequest.setBillAction(udiwmsPostBillRequest.getBillAction());
            if (signRequest.getBillAction().equals("PurchaseWareHouseIn") || signRequest.getBillAction().equals("ReturnWareHouseOut")) {
                return purchaseinSign(signRequest);
            } else if (signRequest.getBillAction().equals("SalesWareHouseOut") || signRequest.getBillAction().equals("ReturnWareHouseIn")) {
                return saleSign(signRequest);
            } else {
                return ResultVOUtils.error(500, "单据类型错误！");
            }
        } else {
            ModifyPruchaseinRequest modifyPruchaseinRequest = new ModifyPruchaseinRequest();
            modifyPruchaseinRequest.setBillAction(udiwmsPostBillRequest.getBillAction());
            List<ModifyPruchaseinRequest.GeneralBillVOBean> generalBillVOBeans = new ArrayList<>();
            for (List<ErpOrderEntity> entities : postMap.values()) {
                ModifyPruchaseinRequest.GeneralBillVOBean generalBillVOBean = new ModifyPruchaseinRequest.GeneralBillVOBean();
                ModifyPruchaseinRequest.GeneralBillVOBean.ParentVOBean parentVOBean = new ModifyPruchaseinRequest.GeneralBillVOBean.ParentVOBean();
                List<ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean> subPurchases = new ArrayList<>();
                for (ErpOrderEntity erpOrderEntity : entities) {
                    if (erpOrderEntity.getErpOrderId() != null) {
                        parentVOBean.setVbillcode(erpOrderEntity.getErpOrderId());
                        ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean childrenVOBean = new ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean();
                        childrenVOBean.setCinventoryid(erpOrderEntity.getGoodsid());
                        if (erpOrderEntity.getCount() != 0) {
                            childrenVOBean.setNinnum(erpOrderEntity.getCount() + "");
                            childrenVOBean.setNoutnum(erpOrderEntity.getCount() + "");
                            subPurchases.add(childrenVOBean);
                        }
                    } else {
                        return ResultVOUtils.error(500, "批次号不匹配，请检查后修改！");
                    }
                }
                generalBillVOBean.setParentVO(parentVOBean);
                generalBillVOBean.setChildrenVO(subPurchases);
                generalBillVOBeans.add(generalBillVOBean);
            }
            modifyPruchaseinRequest.setGeneralBillVO(generalBillVOBeans);
            if (modifyPruchaseinRequest.getBillAction().equals("PurchaseWareHouseIn") || modifyPruchaseinRequest.getBillAction().equals("ReturnWareHouseOut")) {
                return modifyPurchasein(modifyPruchaseinRequest);
            } else if (modifyPruchaseinRequest.getBillAction().equals("SalesWareHouseOut") || modifyPruchaseinRequest.getBillAction().equals("ReturnWareHouseIn")) {
                return modifySale(modifyPruchaseinRequest);
            } else {
                return ResultVOUtils.error(500, "单据类型错误！");
            }
        }

    }

    public BaseResponse signBill(USignRequest signRequest) {
        if (signRequest.getBillAction().equals("PurchaseWareHouseIn") || signRequest.getBillAction().equals("ReturnWareHouseOut")) {
            return purchaseinSign(signRequest);
        } else if (signRequest.getBillAction().equals("SalesWareHouseOut") || signRequest.getBillAction().equals("ReturnWareHouseIn")) {
            return saleSign(signRequest);
        } else {
            return ResultVOUtils.error(500, "单据类型错误！");
        }
    }

    public BaseResponse getOnHand(UdiwmsOnhandRequest udiwmsOnhandRequest) {
        HttpHeaders headers = getNewHeads();
        UOnhandQueryRequest onhandQueryRequest = new UOnhandQueryRequest();
        if (udiwmsOnhandRequest.getInventoryCode() != null) {
            onhandQueryRequest.setInventory(udiwmsOnhandRequest.getInventoryCode());
        } else if (udiwmsOnhandRequest.getInventoryCodes() != null) {
            onhandQueryRequest.setInventorys(udiwmsOnhandRequest.getInventoryCodes());
        }
        onhandQueryRequest.setPage_size(udiwmsOnhandRequest.getLimit() + "");
        onhandQueryRequest.setPage_now(udiwmsOnhandRequest.getPage() + "");
        onhandQueryRequest.setBatchcode(udiwmsOnhandRequest.getBatchNo());
        onhandQueryRequest.setWarehouse(udiwmsOnhandRequest.getWarehouseCode());
        onhandQueryRequest.setCorp(setEntity.getUnitCode());
        onhandQueryRequest.setCalbody(setEntity.getUnitCode());
        UBaseResponse<List<UOnhandQueryResponse>> response = new UCloudStockClient(setEntity.getIpUrl(), headers).onhandQuery(onhandQueryRequest);
        if (response != null) {
            List<UOnhandQueryResponse> uOnhandQueryResponses;
            uOnhandQueryResponses = response.getData().getDatas();
            if (uOnhandQueryResponses != null && uOnhandQueryResponses.size() > 0) {
                List<UdiwmsOnhandResponse> udiwmsOnhandResponses = new ArrayList<>();
                for (UOnhandQueryResponse onhandQueryResponse : uOnhandQueryResponses) {
                    UdiwmsOnhandResponse udiwmsOnhandResponse = new UdiwmsOnhandResponse();
                    udiwmsOnhandResponse.setBatchNo(onhandQueryResponse.getVbatchcode());
                    udiwmsOnhandResponse.setInventoryName(onhandQueryResponse.getCinventory_name());
                    udiwmsOnhandResponse.setInventoryCode(onhandQueryResponse.getCinventory_code());
                    udiwmsOnhandResponse.setCount(onhandQueryResponse.getNnum());
                    udiwmsOnhandResponse.setRegisterCertNo(onhandQueryResponse.getInvtype());
                    udiwmsOnhandResponse.setSpec(onhandQueryResponse.getInvspec());
                    udiwmsOnhandResponse.setWarehouseName(onhandQueryResponse.getCwarehouse_name());
                    udiwmsOnhandResponse.setWarehouseCode(onhandQueryResponse.getCwarehouse_code());
                    udiwmsOnhandResponses.add(udiwmsOnhandResponse);
                }

                PageSimpleResponse<UdiwmsOnhandResponse> pageSimpleResponse = new PageSimpleResponse<>();
                pageSimpleResponse.setTotal(udiwmsOnhandResponses.size() + 0L);
                pageSimpleResponse.setList(udiwmsOnhandResponses);
                return ResultVOUtils.success(pageSimpleResponse);
            }

        }
        return ResultVOUtils.success(response);

    }


    public List<UdiwmsOrderResponse> getPurchasein(UPurchaseinRequest uPurchaseinRequest) {
        HttpHeaders headers = getNewHeads();
        uPurchaseinRequest.setCorp(setEntity.getUnitCode());
        UBaseResponse<List<UPurchaseinQueryResponse>> response = new UCloudStockClient(setEntity.getIpUrl(), headers).purchaseinQuery(uPurchaseinRequest);
        if (response != null) {
            List<UPurchaseinQueryResponse> uPurchaseinQueryResponses = response.getData().getDatas();
            if (uPurchaseinQueryResponses != null && !uPurchaseinQueryResponses.isEmpty()) {
                List<UdiwmsOrderResponse> purchaseinResponses = new ArrayList<>();
                for (UPurchaseinQueryResponse queryResponse : uPurchaseinQueryResponses) {
                    UdiwmsOrderResponse udiwmsOrderResponse = new UdiwmsOrderResponse();
                    UPurchaseinQueryResponse.ParentvoBean parentvoBean = queryResponse.getParentvo();
                    if (parentvoBean != null) {
                        udiwmsOrderResponse.setBilldate(parentvoBean.getDbilldate());
                        udiwmsOrderResponse.setCorpId(parentvoBean.getProvider_code());
                        udiwmsOrderResponse.setCorpName(parentvoBean.getProvider_name());
                        udiwmsOrderResponse.setBillNo(parentvoBean.getVbillcode());
                        udiwmsOrderResponse.setOriginType("采购订单");
                        udiwmsOrderResponse.setSignFlag(parentvoBean.getFbillflag());
                        if (parentvoBean.isFreplenishflag())
                            udiwmsOrderResponse.setBillType("退货出库");
                        else
                            udiwmsOrderResponse.setBillType("采购入库");
                    }
                    List<UPurchaseinQueryResponse.ChildrenvoBean> childrenvoBeans = queryResponse.getChildrenvo();
                    if (childrenvoBeans != null && childrenvoBeans.size() > 0) {
                        List<UdiwmsOrderResponse.SubErpOrder> subPurchases = new ArrayList<>();
                        for (UPurchaseinQueryResponse.ChildrenvoBean childrenvoBean : childrenvoBeans) {
                            UdiwmsOrderResponse.SubErpOrder subErpOrder = new UdiwmsOrderResponse.SubErpOrder();
                            subErpOrder.setProductId(childrenvoBean.getInventory_code());
                            subErpOrder.setProductName(childrenvoBean.getInventory_name());
                            subErpOrder.setSpec(childrenvoBean.getInvspec());
                            subErpOrder.setCount(childrenvoBean.getNinnum());
                            subErpOrder.setReCount(childrenvoBean.getNshouldinnum());
                            subErpOrder.setBatchNo(childrenvoBean.getVbatchcode());
                            subErpOrder.setExpireDate(childrenvoBean.getDvalidate());
                            subPurchases.add(subErpOrder);
                        }
                        udiwmsOrderResponse.setDetailList(subPurchases);
                    }
                    purchaseinResponses.add(udiwmsOrderResponse);
                }
                return purchaseinResponses;
            }
        }
        return null;
    }

    public List<UdiwmsOrderResponse> getSaleout(USaleoutQueryRequest uSaleoutQueryRequest) {

        HttpHeaders headers = getNewHeads();

        uSaleoutQueryRequest.setCorp(setEntity.getUnitCode());
        UBaseResponse<List<USaleoutQueryResponse>> response = new UCloudStockClient(setEntity.getIpUrl(), headers).saleoutQuery(uSaleoutQueryRequest);
        if (response != null) {
            List<USaleoutQueryResponse> uSaleoutQueryResponses = response.getData().getDatas();
            if (uSaleoutQueryResponses != null && !uSaleoutQueryResponses.isEmpty()) {
                List<UdiwmsOrderResponse> purchaseinResponses = new ArrayList<>();
                for (USaleoutQueryResponse queryResponse : uSaleoutQueryResponses) {
                    UdiwmsOrderResponse purchaseinResponse = new UdiwmsOrderResponse();
                    USaleoutQueryResponse.ParentvoBean parentvoBean = queryResponse.getParentvo();
                    if (parentvoBean != null) {
                        purchaseinResponse.setBilldate(parentvoBean.getDbilldate());
                        purchaseinResponse.setCorpId(parentvoBean.getCustomer_code());
                        purchaseinResponse.setCorpName(parentvoBean.getCustomer_name());
                        purchaseinResponse.setBillNo(parentvoBean.getVbillcode());
                        purchaseinResponse.setOriginType("销售订单");
                        purchaseinResponse.setSignFlag(parentvoBean.getFbillflag());
                        if (parentvoBean.isFreplenishflag())
                            purchaseinResponse.setBillType("退货入库");
                        else
                            purchaseinResponse.setBillType("销售出库");
                    }
                    List<USaleoutQueryResponse.ChildrenvoBean> childrenvoBeans = queryResponse.getChildrenvo();
                    if (childrenvoBeans != null && childrenvoBeans.size() > 0) {
                        List<UdiwmsOrderResponse.SubErpOrder> subPurchases = new ArrayList<>();
                        for (USaleoutQueryResponse.ChildrenvoBean childrenvoBean : childrenvoBeans) {
                            UdiwmsOrderResponse.SubErpOrder subPurchase = new UdiwmsOrderResponse.SubErpOrder();
                            subPurchase.setProductId(childrenvoBean.getInventory_code());
                            subPurchase.setProductName(childrenvoBean.getInventory_name());
                            subPurchase.setSpec(childrenvoBean.getInvspec());
                            subPurchase.setReCount(childrenvoBean.getNshouldoutnum());
                            subPurchase.setCount(childrenvoBean.getNoutnum());
                            subPurchase.setBatchNo(childrenvoBean.getVbatchcode());
                            subPurchases.add(subPurchase);
                        }
                        purchaseinResponse.setDetailList(subPurchases);
                    }
                    purchaseinResponses.add(purchaseinResponse);
                }
                return purchaseinResponses;
            }
        }
        return null;
    }

    public BaseResponse modifyPurchasein(ModifyPruchaseinRequest modifyPruchaseinRequest) {
        HttpHeaders headers = getNewHeads();
        if (modifyPruchaseinRequest == null || modifyPruchaseinRequest.getGeneralBillVO() == null) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, "参数不能为null");
        }
        List<ModifyPruchaseinRequest.GeneralBillVOBean> generalBillVOBeans = modifyPruchaseinRequest.getGeneralBillVO();
        for (ModifyPruchaseinRequest.GeneralBillVOBean generalBillVOBean : generalBillVOBeans) {
            UPurchaseinRequest uPurchaseinRequest = new UPurchaseinRequest();
            uPurchaseinRequest.setBillcode(generalBillVOBean.getParentVO().getVbillcode());
            uPurchaseinRequest.setPage_size("1");
            uPurchaseinRequest.setPage_now("1");
            Map date = DateUtil.getYearTRange();
            uPurchaseinRequest.setDate_begin((String) date.get("startDate"));
            uPurchaseinRequest.setDate_end((String) date.get("endDate"));
            uPurchaseinRequest.setCorp(setEntity.getUnitCode());
            UBaseResponse<List<UPurchaseinQueryResponse>> response = new UCloudStockClient(setEntity.getIpUrl(), headers).purchaseinQuery(uPurchaseinRequest);

            List<UPurchaseinQueryResponse> uPurchaseinQueryResponses = response.getData().getDatas();
            if (uPurchaseinQueryResponses != null && !uPurchaseinQueryResponses.isEmpty()) {
                UPurchaseinQueryResponse uPurchaseinQueryResponse = uPurchaseinQueryResponses.get(0);
                UPurchaseinQueryResponse.ParentvoBean parentvoBean = uPurchaseinQueryResponse.getParentvo();
                generalBillVOBean.getParentVO().setCbiztype(parentvoBean.getBiztype_code());
                generalBillVOBean.getParentVO().setCoperatorid(parentvoBean.getOperator_code());
                generalBillVOBean.getParentVO().setCwarehouseid(parentvoBean.getWarehouseid_code());
                generalBillVOBean.getParentVO().setPk_calbody(setEntity.getUnitCode());
                generalBillVOBean.getParentVO().setPk_corp(setEntity.getUnitCode());
                generalBillVOBean.getParentVO().setVnote("扫码修改");
                generalBillVOBean.setChildrenVO(transChild(modifyPruchaseinRequest.getBillAction(), generalBillVOBean, uPurchaseinQueryResponse));
            }
        }
        modifyPruchaseinRequest.setGeneralBillVO(generalBillVOBeans);
        UBaseResponse data = new UCloudStockClient(setEntity.getIpUrl(), headers).purchaseinModify(modifyPruchaseinRequest);
        if (data != null && data.getStatus().equals("success")) {
            return ResultVOUtils.success("修改成功");
        } else {
            if (data != null) {
                return ResultVOUtils.error(500, data.getErrormsg());
            }
            return ResultVOUtils.error(500, "连接U8云下载服务出错！");
        }


    }

    public BaseResponse modifySale(ModifyPruchaseinRequest modifyPruchaseinRequest) {
        HttpHeaders headers = getNewHeads();
        if (modifyPruchaseinRequest == null || modifyPruchaseinRequest.getGeneralBillVO() == null) {
            return ResultVOUtils.error(ResultEnum.PARAM_VERIFY_FALL, "参数不能为null");
        }
        List<ModifyPruchaseinRequest.GeneralBillVOBean> generalBillVOBeans = modifyPruchaseinRequest.getGeneralBillVO();
        for (ModifyPruchaseinRequest.GeneralBillVOBean generalBillVOBean : generalBillVOBeans) {
            USaleoutQueryRequest uPurchaseinRequest = new USaleoutQueryRequest();
            uPurchaseinRequest.setBillcode(generalBillVOBean.getParentVO().getVbillcode());
            uPurchaseinRequest.setPage_size("1");
            uPurchaseinRequest.setPage_now("1");
            Map date = DateUtil.getYearTRange();
            uPurchaseinRequest.setDate_begin((String) date.get("startDate"));
            uPurchaseinRequest.setDate_end((String) date.get("endDate"));
            uPurchaseinRequest.setCorp("1110");
            UBaseResponse<List<USaleoutQueryResponse>> response = new UCloudStockClient(setEntity.getIpUrl(), headers).saleoutQuery(uPurchaseinRequest);

            List<USaleoutQueryResponse> uPurchaseinQueryResponses = response.getData().getDatas();
            if (uPurchaseinQueryResponses != null && !uPurchaseinQueryResponses.isEmpty()) {
                USaleoutQueryResponse uPurchaseinQueryResponse = uPurchaseinQueryResponses.get(0);
                USaleoutQueryResponse.ParentvoBean parentvoBean = uPurchaseinQueryResponse.getParentvo();
                generalBillVOBean.getParentVO().setCbiztype(parentvoBean.getBiztype_code());
                generalBillVOBean.getParentVO().setCoperatorid(parentvoBean.getOperator_code());
                generalBillVOBean.getParentVO().setCwarehouseid(parentvoBean.getWarehouseid_code());
                generalBillVOBean.getParentVO().setPk_calbody("1110");
                generalBillVOBean.getParentVO().setPk_corp("1110");
                generalBillVOBean.getParentVO().setVnote("校验修改");
                generalBillVOBean.getParentVO().setCcustomerid(parentvoBean.getCustomer_code());
                generalBillVOBean.setChildrenVO(transSaleChild(modifyPruchaseinRequest.getBillAction(), generalBillVOBean, uPurchaseinQueryResponse));
            }
        }
        modifyPruchaseinRequest.setGeneralBillVO(generalBillVOBeans);


        UBaseResponse data = new UCloudStockClient(setEntity.getIpUrl(), headers).saleModify(modifyPruchaseinRequest);
        if (data != null && data.getStatus().equals("success")) {
            return ResultVOUtils.success("修改成功");
        } else {
            if (data != null) {
                return ResultVOUtils.error(500, data.getErrormsg());
            }
            return ResultVOUtils.error(500, "连接U8云下载服务出错！");
        }

    }

    public List<ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean> transChild
            (String action, ModifyPruchaseinRequest.GeneralBillVOBean generalBillVOBean, UPurchaseinQueryResponse uPurchaseinQueryResponse) {
        List<ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean> childrenVOBeans = generalBillVOBean.getChildrenVO();
        List<UPurchaseinQueryResponse.ChildrenvoBean> temps = uPurchaseinQueryResponse.getChildrenvo();
        if (childrenVOBeans != null && temps != null) {
            for (ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean childrenVOBean : childrenVOBeans) {
                for (int i = 0; i < temps.size(); i++) {
                    if (childrenVOBean.getCinventoryid().equals(temps.get(i).getInventory_code())) {
//                        childrenVOBean.setNprice(temps.get(i).getNprice() + "");
                        childrenVOBean.setCrowno(temps.get(i).getCrowno());
                        if (action.equals("ReturnWareHouseOut")) {
                            childrenVOBean.setNoutnum((-Integer.parseInt(childrenVOBean.getNinnum())) + "");
                        }
                    }
                }
            }
        }
        return childrenVOBeans;
    }

    public List<ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean> transSaleChild
            (String action, ModifyPruchaseinRequest.GeneralBillVOBean generalBillVOBean, USaleoutQueryResponse uSaleoutQueryResponse) {
        List<ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean> childrenVOBeans = generalBillVOBean.getChildrenVO();
        List<USaleoutQueryResponse.ChildrenvoBean> temps = uSaleoutQueryResponse.getChildrenvo();
        if (childrenVOBeans != null && temps != null) {
            for (ModifyPruchaseinRequest.GeneralBillVOBean.ChildrenVOBean childrenVOBean : childrenVOBeans) {
                for (int i = 0; i < temps.size(); i++) {
                    if (childrenVOBean.getCinventoryid().equals(temps.get(i).getInventory_code())) {
//                        childrenVOBean.setNprice(temps.get(i).getNsaleprice() + "");
//                        childrenVOBean.setNoutnum(temps.get(i).getNoutnum() + "");
                        childrenVOBean.setCrowno(temps.get(i).getCrowno());
                        if (action.equals("ReturnWareHouseIn")) {
                            childrenVOBean.setNoutnum((-Integer.parseInt(childrenVOBean.getNoutnum())) + "");
                        }

                    }

                }
            }
        }
        return childrenVOBeans;
    }


    //采购入库单签字
    public BaseResponse purchaseinSign(USignRequest uSignRequest) {
        HttpHeaders headers = getNewHeads();
        UPurhaseinSignRequest uPurhaseinSignRequest = new UPurhaseinSignRequest();
        UPurhaseinSignRequest.QueryInfoBean queryInfoBean = new UPurhaseinSignRequest.QueryInfoBean();
        Map date = DateUtil.getYearTRange();
        queryInfoBean.setDate_begin((String) date.get("startDate"));
        queryInfoBean.setDate_end((String) date.get("endDate"));
        queryInfoBean.setCalbody(setEntity.getUnitCode());
        queryInfoBean.setCorp(setEntity.getUnitCode());
        queryInfoBean.setBillcode(uSignRequest.getBillcode());
        uPurhaseinSignRequest.setQueryInfo(queryInfoBean);
        UPurhaseinSignRequest.SignInfoBean signInfoBean = new UPurhaseinSignRequest.SignInfoBean();
        signInfoBean.setCoperator(setEntity.getCoperator());
        uPurhaseinSignRequest.setSignInfo(signInfoBean);
        UBaseResponse data = new UCloudStockClient(setEntity.getIpUrl(), headers).purchaseinSign(uPurhaseinSignRequest);
        if (data != null && data.getStatus().equals("success")) {
            return ResultVOUtils.success("修改成功");
        } else {
            if (data != null) {
                return ResultVOUtils.error(500, data.getErrormsg());
            }
            return ResultVOUtils.error(500, "连接U8云下载服务出错！");
        }
    }

    public BaseResponse saleSign(USignRequest uSignRequest) {
        HttpHeaders headers = getNewHeads();
        USaleoutSignRequest uSaleoutSignRequest = new USaleoutSignRequest();
        USaleoutSignRequest.QueryInfoBean queryInfoBean = new USaleoutSignRequest.QueryInfoBean();
        Map date = DateUtil.getYearTRange();
        queryInfoBean.setDate_begin((String) date.get("startDate"));
        queryInfoBean.setDate_end((String) date.get("endDate"));
        queryInfoBean.setCalbody(setEntity.getUnitCode());
        queryInfoBean.setCorp(setEntity.getUnitCode());
        queryInfoBean.setBillcode(uSignRequest.getBillcode());
        uSaleoutSignRequest.setQueryInfo(queryInfoBean);
        USaleoutSignRequest.SignInfoBean signInfoBean = new USaleoutSignRequest.SignInfoBean();
        signInfoBean.setCoperator(setEntity.getCoperator());
        uSaleoutSignRequest.setSignInfo(signInfoBean);
        UBaseResponse data = new UCloudStockClient(setEntity.getIpUrl(), headers).saleOutSign(uSaleoutSignRequest);
        if (data != null && data.getStatus().equals("success")) {
            return ResultVOUtils.success("修改成功");
        } else {
            if (data != null) {
                return ResultVOUtils.error(500, data.getErrormsg());
            }
            return ResultVOUtils.error(500, "连接U8云下载服务出错！");
        }
    }


    public BaseResponse getWarehouse(UdiwmsWarehouseRequest udiwmsWarehouseRequest) {
        return ResultVOUtils.success();
    }
}
