package com.glxp.mipsdl.admin.http;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.TypeReference;
import com.glxp.mipsdl.admin.req.system.PostFileThrOrderRequest;
import com.glxp.mipsdl.admin.req.system.PostThrCorpRequest;
import com.glxp.mipsdl.admin.req.system.PostThrInvProductsRequest;
import com.glxp.mipsdl.admin.req.system.PostThrProductsRequest;
import com.glxp.mipsdl.admin.util.HttpClient;
import com.glxp.mipsdl.common.res.BaseResponse;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpHeaders;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

@Service
public class UdiwmsClient {

    @Value("${UDIWMS_IP}")
    private String udiWmsUrl;


    @Value("${API_KEY}")
    private String apiKey;
    @Value("${API_SECRET}")
    private String apiSecret;
    @Resource
    HttpClient httpClient;

    public HttpHeaders getHeaders() {
        HttpHeaders headers = new HttpHeaders();
        headers.add("Content-Type", "application/json");
        headers.add("api_key", apiKey);
        headers.add("secret_key", apiSecret);
        return headers;
    }

    String[] getHeaderArray() {
        List<String> headArray = new ArrayList<>();
        headArray.add("Content-Type");
        headArray.add("application/json");
        if (StrUtil.isNotEmpty(apiKey)) {
            headArray.add("api_key");
            headArray.add(apiKey);
        }
        if (StrUtil.isNotEmpty(apiSecret)) {
            headArray.add("secret_key");
            headArray.add("apiSecret");
        }

        String[] strArray = new String[headArray.size()];
        headArray.toArray(strArray);
        return strArray;
    }

    public BaseResponse postProducts(PostThrProductsRequest postThrProductsRequest) {
        String response = httpClient.postJson(udiWmsUrl + "/udiwms/thrsys/postThrProducts", postThrProductsRequest, getHeaderArray());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    public BaseResponse postCorps(PostThrCorpRequest postThrCorpRequest) {
        postThrCorpRequest.setUploadType("文件导入");
        String response = httpClient.postJson(udiWmsUrl + "/udiwms/thrsys/postCorps", postThrCorpRequest, getHeaderArray());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    public BaseResponse postOrderDetail(PostFileThrOrderRequest postFileThrOrderRequest) {
        String response = httpClient.postJson(udiWmsUrl + "/udiwms/thrsys/postFileOrder", postFileThrOrderRequest, getHeaderArray());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }

    public BaseResponse postInvProducts(PostThrInvProductsRequest postThrInvProductsRequest) {
        String response = httpClient.postJson(udiWmsUrl + "/udiwms/thrsys/postInvProducts", postThrInvProductsRequest, getHeaderArray());
        BaseResponse baseResponse =
                JSONObject.parseObject(response, new TypeReference<BaseResponse>() {
                });
        return baseResponse;
    }


}
